Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(463)

Unified Diff: remoting/protocol/negotiating_host_authenticator.h

Issue 1755273003: Simplify AuthenticationMethod type and PIN hash handling. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/protocol/negotiating_host_authenticator.h
diff --git a/remoting/protocol/negotiating_host_authenticator.h b/remoting/protocol/negotiating_host_authenticator.h
index 569d15a7947d02928f28d48b9b3e7398016757e3..ed0c8ee6f45c150f5b312faa0d32653e7c5e5aee 100644
--- a/remoting/protocol/negotiating_host_authenticator.h
+++ b/remoting/protocol/negotiating_host_authenticator.h
@@ -29,14 +29,19 @@ class NegotiatingHostAuthenticator : public NegotiatingAuthenticatorBase {
public:
~NegotiatingHostAuthenticator() override;
- // Creates a host authenticator, using a fixed shared secret/PIN hash.
- // If |pairing_registry| is non-nullptr then the Spake2Pair method will
+ // Creates a host authenticator for It2Me host.
+ static scoped_ptr<Authenticator> CreateForIt2Me(
+ const std::string& local_cert,
+ scoped_refptr<RsaKeyPair> key_pair,
+ const std::string& access_code);
+
+ // Creates a host authenticator, using a fixed PIN.
+ // If |pairing_registry| is non-nullptr then the spake2_pair method will
// be offered, supporting PIN-less authentication.
- static scoped_ptr<Authenticator> CreateWithSharedSecret(
+ static scoped_ptr<Authenticator> CreateWithPin(
const std::string& local_cert,
scoped_refptr<RsaKeyPair> key_pair,
- const std::string& shared_secret_hash,
- AuthenticationMethod::HashFunction hash_function,
+ const std::string& pin_hash,
scoped_refptr<PairingRegistry> pairing_registry);
// Creates a host authenticator, using third party authentication.

Powered by Google App Engine
This is Rietveld 408576698